@@ -5,20 +5,21 @@ class Parser:
     """
     Base class for a lexer/parser that has the rules defined as methods
 
-        It could not be loaded or called without Subclass, 
-        
+        It could not be loaded or called without Subclass,
+
         for example: DDLParser
 
         Subclass must include tokens for parser and rules
     """
+
     def __init__(self, content) -> None:
         """ init parser for file """
         self.tables = []
         self.data = content
         self.paren_count = 0
-        self.lexer = lex.lex(object=self, debug=True)
-        self.yacc = yacc.yacc(module=self, debug=True)
-    
+        self.lexer = lex.lex(object=self, debug=False)
+        self.yacc = yacc.yacc(module=self, debug=False)
+
     def run(self):
         """ run lex and yacc on prepared data from files """
         tables = []
@@ -28,12 +29,11 @@ class Parser:
             if line.replace("\n", "").replace("\t", ""):
                 _parse_result = yacc.parse(line)
                 if _parse_result:
-                    print(_parse_result)
-                    if 'table_name' in _parse_result:
+                    if "table_name" in _parse_result:
                         if previous_table_name is not None:
                             tables.append(table)
                             table = []
-                        previous_table_name = _parse_result['table_name']
+                        previous_table_name = _parse_result["table_name"]
                     table.append(_parse_result)
-        tables.append(table)        
-        return tables
\ No newline at end of file
+        tables.append(table)
+        return tables
